pyargcbr.cbrs package
=====================

Submodules
----------

pyargcbr.cbrs.argumentation\_cbr module
---------------------------------------

.. automodule:: pyargcbr.cbrs.argumentation_cbr
    :members:
    :undoc-members:
    :show-inheritance:

pyargcbr.cbrs.cbr module
------------------------

.. automodule:: pyargcbr.cbrs.cbr
    :members:
    :undoc-members:
    :show-inheritance:

pyargcbr.cbrs.domain\_cbr module
--------------------------------

.. automodule:: pyargcbr.cbrs.domain_cbr
    :members:
    :undoc-members:
    :show-inheritance:

pyargcbr.cbrs.lists\_operations module
--------------------------------------

.. automodule:: pyargcbr.cbrs.lists_operations
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pyargcbr.cbrs
    :members:
    :undoc-members:
    :show-inheritance:
